# Utilities API

## Memory Estimation

```{eval-rst}
.. automodule:: pclean.utils.memory_estimate
   :members:
   :undoc-members:
   :show-inheritance:
```

## Partitioning

```{eval-rst}
.. automodule:: pclean.utils.partition
   :members:
   :undoc-members:
   :show-inheritance:
```

## Image Concatenation

```{eval-rst}
.. automodule:: pclean.utils.image_concat
   :members:
   :undoc-members:
   :show-inheritance:
```

## ADIOS2 Checks

```{eval-rst}
.. automodule:: pclean.utils.check_adios2
   :members:
   :undoc-members:
   :show-inheritance:
```

## ADIOS2 Conversion

```{eval-rst}
.. automodule:: pclean.utils.convert_adios2
   :members:
   :undoc-members:
   :show-inheritance:
```
